package App::lcpan::CmdBundle::cwalitee;

our $DATE = '2020-01-19'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: More lcpan subcommands related to cwalitee

__END__

=pod

=encoding UTF-8

=head1 NAME

App::lcpan::CmdBundle::cwalitee - More lcpan subcommands related to cwalitee

=head1 VERSION

This document describes version 0.003 of App::lcpan::CmdBundle::cwalitee (from Perl distribution App-lcpan-CmdBundle-cwalitee), released on 2020-01-19.

=head1 SYNOPSIS

=head1 DESCRIPTION

This bundle provides the following lcpan subcommands:

=over

=item * L<lcpan cwalitees-of-modules-abstracts|App::lcpan::Cmd::cwalitees_of_modules_abstracts>

=item * L<lcpan cwalitee-of-module-abstract|App::lcpan::Cmd::cwalitee_of_module_abstract>

=item * L<lcpan cwalitees-of-scripts-abstracts|App::lcpan::Cmd::cwalitees_of_scripts_abstracts>

=item * L<lcpan cwalitee-of-script-abstract|App::lcpan::Cmd::cwalitee_of_script_abstract>

=item * L<lcpan cwalitee-of-release-changes|App::lcpan::Cmd::cwalitee_of_release_changes>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-lcpan-CmdBundle-cwalitee>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-lcpan-CmdBundle-cwalitee>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-lcpan-CmdBundle-cwalitee>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<lcpan>

L<Cwalitee::Common>

L<CPAN::Changes::Cwalitee>

L<Module::Abstract::Cwalitee>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2019 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
